# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_datashard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ydb/core/protos/counters_datashard.proto\x12\x12NKikimr.NDataShard\x1a\x1eydb/core/protos/counters.proto*\xe0\x07\n\x0f\x45SimpleCounters\x12$\n\x11\x43OUNTER_TX_IN_FLY\x10\x00\x1a\r\x82\xd6\x1b\t\n\x07TxInFly\x12\'\n\x12\x43OUNTER_STATE_WORK\x10\x01\x1a\x0f\x82\xd6\x1b\x0b\n\tStateWork\x12\x30\n\x17\x43OUNTER_TX_COMPLETE_LAG\x10\x02\x1a\x13\x82\xd6\x1b\x0f\n\rTxCompleteLag\x12=\n\x1e\x43OUNTER_OUT_READSETS_IN_FLIGHT\x10\x03\x1a\x19\x82\xd6\x1b\x15\n\x13OutReadSetsInFlight\x12\x37\n\x1b\x43OUNTER_IMMEDIATE_TX_IN_FLY\x10\x04\x1a\x16\x82\xd6\x1b\x12\n\x10ImmediateTxInFly\x12:\n\x1c\x43OUNTER_IMMEDIATE_TX_DELAYED\x10\x05\x1a\x18\x82\xd6\x1b\x14\n\x12ImmediateTxDelayed\x12\x39\n\x1c\x43OUNTER_SCAN_TX_COMPLETE_LAG\x10\x06\x1a\x17\x82\xd6\x1b\x13\n\x11ScanTxCompleteLag\x12\x36\n\x1a\x43OUNTER_PROPOSE_QUEUE_SIZE\x10\x07\x1a\x16\x82\xd6\x1b\x12\n\x10ProposeQueueSize\x12?\n COUNTER_SPLIT_SRC_WAIT_TX_IN_FLY\x10\x08\x1a\x19\x82\xd6\x1b\x15\n\x13SplitSrcWaitTxInFly\x12R\n*COUNTER_SPLIT_SRC_WAIT_IMMEDIATE_TX_IN_FLY\x10\t\x1a\"\x82\xd6\x1b\x1e\n\x1cSplitSrcWaitImmediateTxInFly\x12N\n(COUNTER_MVCC_STATE_CHANGE_WAIT_TX_IN_FLY\x10\n\x1a \x82\xd6\x1b\x1c\n\x1aMvccStateChangeWaitTxInFly\x12\x61\n2COUNTER_MVCC_STATE_CHANGE_WAIT_IMMEDIATE_TX_IN_FLY\x10\x0b\x1a)\x82\xd6\x1b%\n#MvccStateChangeWaitImmediateTxInFly\x12+\n\x14\x43OUNTER_MVCC_ENABLED\x10\x0c\x1a\x11\x82\xd6\x1b\r\n\x0bMvccEnabled\x12\x34\n\x19\x43OUNTER_CHANGE_QUEUE_SIZE\x10\r\x1a\x15\x82\xd6\x1b\x11\n\x0f\x43hangeQueueSize\x12>\n\x1e\x43OUNTER_READ_ITERATORS_WAITING\x10\x0e\x1a\x1a\x82\xd6\x1b\x16\n\x14ReadIteratorsWaiting\x12:\n\x1c\x43OUNTER_READ_ITERATORS_COUNT\x10\x0f\x1a\x18\x82\xd6\x1b\x14\n\x12ReadIteratorsCount*\x9a,\n\x13\x45\x43umulativeCounters\x12\x1f\n\x0e\x43OUNTER_REQ_RO\x10\x00\x1a\x0b\x82\xd6\x1b\x07\n\x05ReqRo\x12\x32\n\x17\x43OUNTER_PREPARE_REQUEST\x10\x01\x1a\x15\x82\xd6\x1b\x11\n\x0fPrepareRequests\x12.\n\x15\x43OUNTER_PREPARE_ERROR\x10\x02\x1a\x13\x82\xd6\x1b\x0f\n\rPrepareErrors\x12\x35\n\x19\x43OUNTER_PREPARE_IMMEDIATE\x10\x03\x1a\x16\x82\xd6\x1b\x12\n\x10PrepareImmediate\x12\x31\n\x17\x43OUNTER_PREPARE_SUCCESS\x10\x04\x1a\x14\x82\xd6\x1b\x10\n\x0ePrepareSuccess\x12\x33\n\x18\x43OUNTER_PREPARE_COMPLETE\x10\x05\x1a\x15\x82\xd6\x1b\x11\n\x0fPrepareComplete\x12-\n\x15\x43OUNTER_PREPARE_DIRTY\x10\x06\x1a\x12\x82\xd6\x1b\x0e\n\x0cPrepareDirty\x12\x37\n\x1a\x43OUNTER_PREPARE_OVERLOADED\x10\x07\x1a\x17\x82\xd6\x1b\x13\n\x11PrepareOverloaded\x12\x34\n\x19\x43OUNTER_PLAN_STEP_IGNORED\x10\x08\x1a\x15\x82\xd6\x1b\x11\n\x0fPlanStepIgnored\x12\x36\n\x1a\x43OUNTER_PLAN_STEP_ACCEPTED\x10\t\x1a\x16\x82\xd6\x1b\x12\n\x10PlanStepAccepted\x12\x45\n\"COUNTER_TX_PROGRESS_SHARD_INACTIVE\x10\n\x1a\x1d\x82\xd6\x1b\x19\n\x17TxProgressShardInactive\x12?\n\x1f\x43OUNTER_TX_PROGRESS_QUEUE_EMPTY\x10\x0b\x1a\x1a\x82\xd6\x1b\x16\n\x14TxProgressQueueEmpty\x12\x38\n\x1b\x43OUNTER_TX_PROGRESS_CLEANUP\x10\x0c\x1a\x17\x82\xd6\x1b\x13\n\x11TxProgressCleanup\x12:\n\x1c\x43OUNTER_TX_PROGRESS_OUTDATED\x10\r\x1a\x18\x82\xd6\x1b\x14\n\x12TxProgressOutdated\x12<\n\x1d\x43OUNTER_TX_PROGRESS_DUPLICATE\x10\x0e\x1a\x19\x82\xd6\x1b\x15\n\x13TxProgressDuplicate\x12\x34\n\x19\x43OUNTER_TX_PROGRESS_DIRTY\x10\x0f\x1a\x15\x82\xd6\x1b\x11\n\x0fTxProgressDirty\x12\x32\n\x16\x43OUNTER_TX_PROGRESS_EV\x10\x10\x1a\x16\x82\xd6\x1b\x12\n\x10TxProgressEvents\x12:\n\x1c\x43OUNTER_TX_CLEANUP_SCHEDULED\x10\x11\x1a\x18\x82\xd6\x1b\x14\n\x12TxCleanupScheduled\x12\x32\n\x18\x43OUNTER_TX_PROGRESS_IDLE\x10\x12\x1a\x14\x82\xd6\x1b\x10\n\x0eTxProgressIdle\x12#\n\x10\x43OUNTER_ACK_SENT\x10\x13\x1a\r\x82\xd6\x1b\t\n\x07\x41\x63kSent\x12\x32\n\x18\x43OUNTER_ACK_SENT_DELAYED\x10\x14\x1a\x14\x82\xd6\x1b\x10\n\x0e\x41\x63kSentDelayed\x12\x36\n\x1a\x43OUNTER_CANCEL_TX_NOTFOUND\x10\x15\x1a\x16\x82\xd6\x1b\x12\n\x10\x43\x61ncelTxNotFound\x12:\n\x1c\x43OUNTER_MINIKQL_PROGRAM_SIZE\x10\x16\x1a\x18\x82\xd6\x1b\x14\n\x12MiniKQLProgramSize\x12<\n\x1e\x43OUNTER_ENGINE_HOST_SELECT_ROW\x10\x17\x1a\x18\x82\xd6\x1b\x14\n\x12\x45ngineHostRowReads\x12@\n COUNTER_ENGINE_HOST_SELECT_RANGE\x10\x18\x1a\x1a\x82\xd6\x1b\x16\n\x14\x45ngineHostRangeReads\x12>\n\x1e\x43OUNTER_ENGINE_HOST_UPDATE_ROW\x10\x19\x1a\x1a\x82\xd6\x1b\x16\n\x14\x45ngineHostRowUpdates\x12<\n\x1d\x43OUNTER_ENGINE_HOST_ERASE_ROW\x10\x1a\x1a\x19\x82\xd6\x1b\x15\n\x13\x45ngineHostRowErases\x12\x35\n\x19\x43OUNTER_PREPARE_CANCELLED\x10\x1b\x1a\x16\x82\xd6\x1b\x12\n\x10PrepareCancelled\x12\x36\n\x1a\x43OUNTER_READSET_SENT_COUNT\x10\x1c\x1a\x16\x82\xd6\x1b\x12\n\x10ReadsetSentCount\x12\x34\n\x19\x43OUNTER_READSET_SENT_SIZE\x10\x1d\x1a\x15\x82\xd6\x1b\x11\n\x0fReadsetSentSize\x12>\n\x1e\x43OUNTER_READSET_RECEIVED_COUNT\x10\x1e\x1a\x1a\x82\xd6\x1b\x16\n\x14ReadsetReceivedCount\x12<\n\x1d\x43OUNTER_READSET_RECEIVED_SIZE\x10\x1f\x1a\x19\x82\xd6\x1b\x15\n\x13ReadsetReceivedSize\x12.\n\x16\x43OUNTER_TX_RESULT_SIZE\x10 \x1a\x12\x82\xd6\x1b\x0e\n\x0cTxResultSize\x12/\n\x16\x43OUNTER_LOCKS_REJECTED\x10!\x1a\x13\x82\xd6\x1b\x0f\n\rLocksRejected\x12/\n\x16\x43OUNTER_LOCKS_ACQUIRED\x10\"\x1a\x13\x82\xd6\x1b\x0f\n\rLocksAcquired\x12-\n\x15\x43OUNTER_LOCKS_EVICTED\x10#\x1a\x12\x82\xd6\x1b\x0e\n\x0cLocksEvicted\x12+\n\x14\x43OUNTER_LOCKS_BROKEN\x10$\x1a\x11\x82\xd6\x1b\r\n\x0bLocksBroken\x12+\n\x14\x43OUNTER_LOCKS_ERASED\x10%\x1a\x11\x82\xd6\x1b\r\n\x0bLocksErased\x12-\n\x15\x43OUNTER_LOCKS_REMOVED\x10&\x1a\x12\x82\xd6\x1b\x0e\n\x0cLocksRemoved\x12\x38\n\x1b\x43OUNTER_LOCKS_REJECT_BROKEN\x10\'\x1a\x17\x82\xd6\x1b\x13\n\x11LocksRejectBroken\x12\'\n\x12\x43OUNTER_LOCKS_LOST\x10(\x1a\x0f\x82\xd6\x1b\x0b\n\tLocksLost\x12\x43\n!COUNTER_INACTIVE_TX_DATA_RELEASES\x10)\x1a\x1c\x82\xd6\x1b\x18\n\x16InactiveTxDataReleases\x12\x39\n\x1b\x43OUNTER_PIPELINE_OVERLOADED\x10*\x1a\x18\x82\xd6\x1b\x14\n\x12PipelineOverloaded\x12\x38\n\x1b\x43OUNTER_TX_PROGRESS_DELAYED\x10+\x1a\x17\x82\xd6\x1b\x13\n\x11TxProgressDelayed\x12+\n\x14\x43OUNTER_TX_REORDERED\x10,\x1a\x11\x82\xd6\x1b\r\n\x0bTxReordered\x12\x30\n\x15\x43OUNTER_TX_WAIT_ORDER\x10-\x1a\x15\x82\xd6\x1b\x11\n\x0fTxCannotReorder\x12*\n\x14\x43OUNTER_TX_WAIT_DATA\x10.\x1a\x10\x82\xd6\x1b\x0c\n\nTxWaitData\x12\x33\n\x19\x43OUNTER_TX_WAIT_READ_SETS\x10/\x1a\x14\x82\xd6\x1b\x10\n\x0eTxWaitReadSets\x12\x32\n\x18\x43OUNTER_TX_WAIT_RESOURCE\x10\x30\x1a\x14\x82\xd6\x1b\x10\n\x0eTxWaitResource\x12\x34\n\x19\x43OUNTER_LOCKS_WHOLE_SHARD\x10\x31\x1a\x15\x82\xd6\x1b\x11\n\x0fLocksWholeShard\x12\x46\n$COUNTER_ENGINE_HOST_SELECT_ROW_BYTES\x10\x32\x1a\x1c\x82\xd6\x1b\x18\n\x16\x45ngineHostRowReadBytes\x12H\n%COUNTER_ENGINE_HOST_SELECT_RANGE_ROWS\x10\x33\x1a\x1d\x82\xd6\x1b\x19\n\x17\x45ngineHostRangeReadRows\x12J\n&COUNTER_ENGINE_HOST_SELECT_RANGE_BYTES\x10\x34\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x45ngineHostRangeReadBytes\x12H\n$COUNTER_ENGINE_HOST_UPDATE_ROW_BYTES\x10\x35\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x45ngineHostRowUpdateBytes\x12\x46\n#COUNTER_ENGINE_HOST_ERASE_ROW_BYTES\x10\x36\x1a\x1d\x82\xd6\x1b\x19\n\x17\x45ngineHostRowEraseBytes\x12\x38\n\x1b\x43OUNTER_PLANNED_TX_COMPLETE\x10\x37\x1a\x17\x82\xd6\x1b\x13\n\x11PlannedTxComplete\x12\x39\n\x1c\x43OUNTER_PREPARE_OUT_OF_SPACE\x10\x38\x1a\x17\x82\xd6\x1b\x13\n\x11PrepareOutOfSpace\x12>\n\x1e\x43OUNTER_IMMEDIATE_TX_CANCELLED\x10\x39\x1a\x1a\x82\xd6\x1b\x16\n\x14ImmediateTxCancelled\x12:\n\x1c\x43OUNTER_PLANNED_TX_CANCELLED\x10:\x1a\x18\x82\xd6\x1b\x14\n\x12PlannedTxCancelled\x12)\n\x13\x43OUNTER_UPLOAD_ROWS\x10;\x1a\x10\x82\xd6\x1b\x0c\n\nUploadRows\x12\x34\n\x19\x43OUNTER_UPLOAD_ROWS_BYTES\x10<\x1a\x15\x82\xd6\x1b\x11\n\x0fUploadRowsBytes\x12X\n*COUNTER_ENGINE_HOST_SELECT_RANGE_ROW_SKIPS\x10=\x1a(\x82\xd6\x1b$\n\"EngineHostRangeReadDeletedRowSkips\x12\x34\n\x19\x43OUNTER_READ_COLUMNS_ROWS\x10>\x1a\x15\x82\xd6\x1b\x11\n\x0fReadColumnsRows\x12\x36\n\x1a\x43OUNTER_READ_COLUMNS_BYTES\x10?\x1a\x16\x82\xd6\x1b\x12\n\x10ReadColumnsBytes\x12+\n\x14\x43OUNTER_SCANNED_ROWS\x10@\x1a\x11\x82\xd6\x1b\r\n\x0bScannedRows\x12-\n\x15\x43OUNTER_SCANNED_BYTES\x10\x41\x1a\x12\x82\xd6\x1b\x0e\n\x0cScannedBytes\x12\x38\n\x18\x43OUNTER_PROPOSE_QUEUE_EV\x10\x42\x1a\x1a\x82\xd6\x1b\x16\n\x14TxProposeQueueEvents\x12\x38\n\x1b\x43OUNTER_BULK_UPSERT_SUCCESS\x10\x43\x1a\x17\x82\xd6\x1b\x13\n\x11\x42ulkUpsertSuccess\x12\x34\n\x19\x43OUNTER_BULK_UPSERT_ERROR\x10\x44\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42ulkUpsertError\x12>\n\x1e\x43OUNTER_BULK_UPSERT_OVERLOADED\x10\x45\x1a\x1a\x82\xd6\x1b\x16\n\x14\x42ulkUpsertOverloaded\x12\x36\n\x1a\x43OUNTER_ERASE_ROWS_SUCCESS\x10\x46\x1a\x16\x82\xd6\x1b\x12\n\x10\x45raseRowsSuccess\x12\x32\n\x18\x43OUNTER_ERASE_ROWS_ERROR\x10G\x1a\x14\x82\xd6\x1b\x10\n\x0e\x45raseRowsError\x12<\n\x1d\x43OUNTER_ERASE_ROWS_OVERLOADED\x10H\x1a\x19\x82\xd6\x1b\x15\n\x13\x45raseRowsOverloaded\x12\'\n\x12\x43OUNTER_ERASE_ROWS\x10I\x1a\x0f\x82\xd6\x1b\x0b\n\tEraseRows\x12\x44\n\x1f\x43OUNTER_BUILD_DEPENDENCIES_USEC\x10J\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x42uildDependenciesMicrosec\x12\x36\n\x18\x43OUNTER_APPLY_LOCKS_USEC\x10K\x1a\x18\x82\xd6\x1b\x14\n\x12\x41pplyLocksMicrosec\x12<\n\x1e\x43OUNTER_TX_NOT_ENOUGH_MEMORY_1\x10L\x1a\x18\x82\xd6\x1b\x14\n\x12TxNotEnoughMemory1\x12<\n\x1e\x43OUNTER_TX_NOT_ENOUGH_MEMORY_2\x10M\x1a\x18\x82\xd6\x1b\x14\n\x12TxNotEnoughMemory2\x12<\n\x1e\x43OUNTER_TX_NOT_ENOUGH_MEMORY_3\x10N\x1a\x18\x82\xd6\x1b\x14\n\x12TxNotEnoughMemory3\x12<\n\x1e\x43OUNTER_TX_NOT_ENOUGH_MEMORY_4\x10O\x1a\x18\x82\xd6\x1b\x14\n\x12TxNotEnoughMemory4\x12\x37\n\x1b\x43OUNTER_TX_TABLET_NOT_READY\x10P\x1a\x16\x82\xd6\x1b\x12\n\x10TxTabletNotReady\x12:\n COUNTER_TX_BACKGROUND_COMPACTION\x10Q\x1a\x14\x82\xd6\x1b\x10\n\x0eTxCompactTable\x12N\n+COUNTER_TX_BACKGROUND_COMPACTION_NOT_NEEDED\x10R\x1a\x1d\x82\xd6\x1b\x19\n\x17TxCompactTableNotNeeded\x12X\n0COUNTER_TX_BACKGROUND_COMPACTION_FAILED_BORROWED\x10S\x1a\"\x82\xd6\x1b\x1e\n\x1cTxCompactTableFailedBorrowed\x12R\n-COUNTER_TX_BACKGROUND_COMPACTION_FAILED_START\x10T\x1a\x1f\x82\xd6\x1b\x1b\n\x19TxCompactTableFailedStart\x12;\n\x1c\x43OUNTER_FULL_COMPACTION_DONE\x10U\x1a\x19\x82\xd6\x1b\x15\n\x13\x46ullCompactionCount\x12T\n.COUNTER_TX_BACKGROUND_COMPACTION_FAILED_LOANED\x10V\x1a \x82\xd6\x1b\x1c\n\x1aTxCompactTableFailedLoaned\x12\x38\n\x1b\x43OUNTER_TX_COMPACT_BORROWED\x10W\x1a\x17\x82\xd6\x1b\x13\n\x11TxCompactBorrowed\x12@\n\x1f\x43OUNTER_CHANGE_RECORDS_ENQUEUED\x10X\x1a\x1b\x82\xd6\x1b\x17\n\x15\x43hangeRecordsEnqueued\x12>\n\x1e\x43OUNTER_CHANGE_RECORDS_REMOVED\x10Y\x1a\x1a\x82\xd6\x1b\x16\n\x14\x43hangeRecordsRemoved\x12=\n\x1e\x43OUNTER_READ_ITERATOR_NO_QUOTA\x10Z\x1a\x19\x82\xd6\x1b\x15\n\x13ReadIteratorNoQuota\x12L\n&COUNTER_READ_ITERATOR_MAX_ROWS_REACHED\x10[\x1a \x82\xd6\x1b\x1c\n\x1aReadIteratorMaxRowsReached\x12L\n&COUNTER_READ_ITERATOR_MAX_TIME_REACHED\x10\\\x1a \x82\xd6\x1b\x1c\n\x1aReadIteratorMaxTimeReached\x12?\n\x1f\x43OUNTER_READ_ITERATOR_ROWS_READ\x10]\x1a\x1a\x82\xd6\x1b\x16\n\x14ReadIteratorRowsRead\x12\x41\n COUNTER_READ_ITERATOR_BYTES_READ\x10^\x1a\x1b\x82\xd6\x1b\x17\n\x15ReadIteratorBytesRead\x12:\n\x1c\x43OUNTER_READ_ITERATOR_CANCEL\x10_\x1a\x18\x82\xd6\x1b\x14\n\x12ReadIteratorCancel*\xee\x19\n\x13\x45PercentileCounters\x12Q\n(COUNTER_PREPARE_SUCCESS_COMPLETE_LATENCY\x10\x00\x1a#\x82\xd6\x1b\x1f\n\x1dPrepareSuccessCompleteLatency\x12V\n+COUNTER_ACCEPTED_PLAN_STEP_COMPLETE_LATENCY\x10\x01\x1a%\x82\xd6\x1b!\n\x1f\x41\x63\x63\x65ptedPlanStepCompleteLatency\x12I\n$COUNTER_TX_PROGRESS_COMPLETE_LATENCY\x10\x02\x1a\x1f\x82\xd6\x1b\x1b\n\x19TxProgressCompleteLatency\x12?\n\x1f\x43OUNTER_PLAN_TO_EXECUTE_LATENCY\x10\x03\x1a\x1a\x82\xd6\x1b\x16\n\x14PlanToExecuteLatency\x12:\n\x1c\x43OUNTER_PREPARE_EXEC_LATENCY\x10\x04\x1a\x18\x82\xd6\x1b\x14\n\x12PrepareExecLatency\x12\x41\n COUNTER_TX_PROGRESS_EXEC_LATENCY\x10\x05\x1a\x1b\x82\xd6\x1b\x17\n\x15TxProgressExecLatency\x12\xbc\x01\n\x1e\x43OUNTER_LOCKS_ACTIVE_PER_SHARD\x10\x06\x1a\x97\x01\x82\xd6\x1b\x92\x01\n\x13LocksActivePerShard\x12\x05\x08\x00\x12\x01\x30\x12\x08\x08\n\x12\x04\x31-10\x12\n\x08\x64\x12\x06\x31\x30-100\x12\x0c\x08\xf4\x03\x12\x07\x31\x30\x30-500\x12\r\x08\xe8\x07\x12\x08\x35\x30\x30-1000\x12\x0e\x08\xa0\x1f\x12\t1000-4000\x12\x0e\x08\xc0>\x12\t4000-8000\x12\x0f\x08\xe0]\x12\n8000-12000\x12\x10\x08\x80}\x12\x0b\x31\x32\x30\x30\x30-16000\x12\xbc\x01\n\x1e\x43OUNTER_LOCKS_BROKEN_PER_SHARD\x10\x07\x1a\x97\x01\x82\xd6\x1b\x92\x01\n\x13LocksBrokenPerShard\x12\x05\x08\x00\x12\x01\x30\x12\x08\x08\n\x12\x04\x31-10\x12\n\x08\x64\x12\x06\x31\x30-100\x12\x0c\x08\xf4\x03\x12\x07\x31\x30\x30-500\x12\r\x08\xe8\x07\x12\x08\x35\x30\x30-1000\x12\x0e\x08\xa0\x1f\x12\t1000-4000\x12\x0e\x08\xc0>\x12\t4000-8000\x12\x0f\x08\xe0]\x12\n8000-12000\x12\x10\x08\x80}\x12\x0b\x31\x32\x30\x30\x30-16000\x12/\n\x16\x43OUNTER_LOCKS_LIFETIME\x10\x08\x1a\x13\x82\xd6\x1b\x0f\n\rLocksLifetime\x12<\n\x1d\x43OUNTER_PROPOSE_QUEUE_LATENCY\x10\t\x1a\x19\x82\xd6\x1b\x15\n\x13ProposeQueueLatency\x12\xdb\x02\n\x1d\x43OUNTER_HIST_RANGE_READ_BYTES\x10\n\x1a\xb7\x02\x82\xd6\x1b\xb2\x02\n(HIST(DataShard/EngineHostRangeReadBytes)\x12\x05\x08\x00\x12\x01\x30\x12\t\x08\x80\x08\x12\x04\x31\x30\x32\x34\x12\t\x08\x80\x10\x12\x04\x32\x30\x34\x38\x12\t\x08\x80 \x12\x04\x34\x30\x39\x36\x12\t\x08\x80@\x12\x04\x38\x31\x39\x32\x12\x0b\x08\x80\x80\x01\x12\x05\x31\x36\x33\x38\x34\x12\x0b\x08\x80\x80\x02\x12\x05\x33\x32\x37\x36\x38\x12\x0b\x08\x80\x80\x04\x12\x05\x36\x35\x35\x33\x36\x12\x0c\x08\x80\x80\x08\x12\x06\x31\x33\x31\x30\x37\x32\x12\x0c\x08\x80\x80\x10\x12\x06\x32\x36\x32\x31\x34\x34\x12\x0c\x08\x80\x80 \x12\x06\x35\x32\x34\x32\x38\x38\x12\r\x08\x80\x80@\x12\x07\x31\x30\x34\x38\x35\x37\x36\x12\x0e\x08\x80\x80\x80\x01\x12\x07\x32\x30\x39\x37\x31\x35\x32\x12\x0e\x08\x80\x80\x80\x02\x12\x07\x34\x31\x39\x34\x33\x30\x34\x12\x0e\x08\x80\x80\x80\x04\x12\x07\x38\x33\x38\x38\x36\x30\x38\x12\x0f\x08\x80\x80\x80\x08\x12\x08\x31\x36\x37\x37\x37\x32\x31\x36\x12\x0f\x08\x80\x80\x80\x10\x12\x08\x33\x33\x35\x35\x34\x34\x33\x32\x12\x0f\x08\x80\x80\x80 \x12\x08\x36\x37\x31\x30\x38\x38\x36\x34\x12\x10\x08\x80\x80\x80@\x12\t134217728\x12\x83\x01\n\x1f\x43OUNTER_SELECT_ROWS_PER_REQUEST\x10\x0b\x1a^\x82\xd6\x1bZ\n\x14SelectRowsPerRequest\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x06\x08\n\x12\x02\x31\x30\x12\x07\x08\x64\x12\x03\x31\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12\n\x08\x90N\x12\x05\x31\x30\x30\x30\x30\x12\x0c\x08\xa0\x8d\x06\x12\x06\x31\x30\x30\x30\x30\x30\x12\x8a\x01\n#COUNTER_RANGE_READ_ROWS_PER_REQUEST\x10\x0c\x1a\x61\x82\xd6\x1b]\n\x17RangeReadRowsPerRequest\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x06\x08\n\x12\x02\x31\x30\x12\x07\x08\x64\x12\x03\x31\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12\n\x08\x90N\x12\x05\x31\x30\x30\x30\x30\x12\x0c\x08\xa0\x8d\x06\x12\x06\x31\x30\x30\x30\x30\x30\x12\xd4\x01\n\x1d\x43OUNTER_PLAN_QUEUE_LATENCY_MS\x10\r\x1a\xb0\x01\x82\xd6\x1b\xab\x01\n\x12PlanQueueLatencyMs\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x02\x12\x01\x32\x12\x05\x08\x05\x12\x01\x35\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x19\x12\x02\x32\x35\x12\x06\x08\x32\x12\x02\x35\x30\x12\x07\x08}\x12\x03\x31\x32\x35\x12\x08\x08\xfa\x01\x12\x03\x32\x35\x30\x12\x08\x08\xf4\x03\x12\x03\x35\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12\t\x08\xd0\x0f\x12\x04\x32\x30\x30\x30\x12\t\x08\x88\'\x12\x04\x35\x30\x30\x30\x12\n\x08\x90N\x12\x05\x31\x30\x30\x30\x30\x12\n\x08\x98u\x12\x05\x31\x35\x30\x30\x30\x12\x0b\x08\xb0\xea\x01\x12\x05\x33\x30\x30\x30\x30\x12\xe2\x01\n$COUNTER_WAIT_DEPENDENCIES_LATENCY_MS\x10\x0e\x1a\xb7\x01\x82\xd6\x1b\xb2\x01\n\x19WaitDependenciesLatencyMs\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x02\x12\x01\x32\x12\x05\x08\x05\x12\x01\x35\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x19\x12\x02\x32\x35\x12\x06\x08\x32\x12\x02\x35\x30\x12\x07\x08}\x12\x03\x31\x32\x35\x12\x08\x08\xfa\x01\x12\x03\x32\x35\x30\x12\x08\x08\xf4\x03\x12\x03\x35\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12\t\x08\xd0\x0f\x12\x04\x32\x30\x30\x30\x12\t\x08\x88\'\x12\x04\x35\x30\x30\x30\x12\n\x08\x90N\x12\x05\x31\x30\x30\x30\x30\x12\n\x08\x98u\x12\x05\x31\x35\x30\x30\x30\x12\x0b\x08\xb0\xea\x01\x12\x05\x33\x30\x30\x30\x30\x12\xda\x01\n COUNTER_WAIT_READSETS_LATENCY_MS\x10\x0f\x1a\xb3\x01\x82\xd6\x1b\xae\x01\n\x15WaitReadSetsLatencyMs\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x02\x12\x01\x32\x12\x05\x08\x05\x12\x01\x35\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x19\x12\x02\x32\x35\x12\x06\x08\x32\x12\x02\x35\x30\x12\x07\x08}\x12\x03\x31\x32\x35\x12\x08\x08\xfa\x01\x12\x03\x32\x35\x30\x12\x08\x08\xf4\x03\x12\x03\x35\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12\t\x08\xd0\x0f\x12\x04\x32\x30\x30\x30\x12\t\x08\x88\'\x12\x04\x35\x30\x30\x30\x12\n\x08\x90N\x12\x05\x31\x30\x30\x30\x30\x12\n\x08\x98u\x12\x05\x31\x35\x30\x30\x30\x12\x0b\x08\xb0\xea\x01\x12\x05\x33\x30\x30\x30\x30\x12\xd8\x01\n\x1f\x43OUNTER_WAIT_EXECUTE_LATENCY_MS\x10\x10\x1a\xb2\x01\x82\xd6\x1b\xad\x01\n\x14WaitExecuteLatencyMs\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x02\x12\x01\x32\x12\x05\x08\x05\x12\x01\x35\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x19\x12\x02\x32\x35\x12\x06\x08\x32\x12\x02\x35\x30\x12\x07\x08}\x12\x03\x31\x32\x35\x12\x08\x08\xfa\x01\x12\x03\x32\x35\x30\x12\x08\x08\xf4\x03\x12\x03\x35\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12\t\x08\xd0\x0f\x12\x04\x32\x30\x30\x30\x12\t\x08\x88\'\x12\x04\x35\x30\x30\x30\x12\n\x08\x90N\x12\x05\x31\x30\x30\x30\x30\x12\n\x08\x98u\x12\x05\x31\x35\x30\x30\x30\x12\x0b\x08\xb0\xea\x01\x12\x05\x33\x30\x30\x30\x30\x12\xd4\x01\n\x1d\x43OUNTER_WAIT_TOTAL_LATENCY_MS\x10\x11\x1a\xb0\x01\x82\xd6\x1b\xab\x01\n\x12WaitTotalLatencyMs\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x02\x12\x01\x32\x12\x05\x08\x05\x12\x01\x35\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x19\x12\x02\x32\x35\x12\x06\x08\x32\x12\x02\x35\x30\x12\x07\x08}\x12\x03\x31\x32\x35\x12\x08\x08\xfa\x01\x12\x03\x32\x35\x30\x12\x08\x08\xf4\x03\x12\x03\x35\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12\t\x08\xd0\x0f\x12\x04\x32\x30\x30\x30\x12\t\x08\x88\'\x12\x04\x35\x30\x30\x30\x12\n\x08\x90N\x12\x05\x31\x30\x30\x30\x30\x12\n\x08\x98u\x12\x05\x31\x35\x30\x30\x30\x12\x0b\x08\xb0\xea\x01\x12\x05\x33\x30\x30\x30\x30\x12\x9f\x01\n!COUNTER_READ_ITERATOR_LIFETIME_MS\x10\x12\x1ax\x82\xd6\x1bt\n\x16ReadIteratorLifetimeMs\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x02\x12\x01\x32\x12\x05\x08\x05\x12\x01\x35\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x19\x12\x02\x32\x35\x12\x06\x08\x32\x12\x02\x35\x30\x12\x07\x08}\x12\x03\x31\x32\x35\x12\x08\x08\xfa\x01\x12\x03\x32\x35\x30\x12\x08\x08\xf4\x03\x12\x03\x35\x30\x30\x12\t\x08\xe8\x07\x12\x04\x31\x30\x30\x30\x12x\n*COUNTER_READ_ITERATOR_ITERATION_LATENCY_MS\x10\x13\x1aH\x82\xd6\x1b\x44\n\x1eReadIteratorIterationLatencyMs\x12\x05\x08\x00\x12\x01\x30\x12\x05\x08\x01\x12\x01\x31\x12\x05\x08\x02\x12\x01\x32\x12\x05\x08\x05\x12\x01\x35\x12\x06\x08\n\x12\x02\x31\x30\x1a\xdb\x02\x92\xd6\x1b\xd6\x02\x12\x11\x08\xf4\x03\x12\x0c(1) < 500 us\x12\x11\x08\xe8\x07\x12\x0c(2) 0.5-1 ms\x12\x0f\x08\xd0\x0f\x12\n(3) 1-2 ms\x12\x0f\x08\xa0\x1f\x12\n(4) 2-4 ms\x12\x0f\x08\xc0>\x12\n(5) 4-8 ms\x12\x10\x08\x80}\x12\x0b(6) 8-16 ms\x12\x12\x08\x80\xfa\x01\x12\x0c(7) 16-32 ms\x12\x12\x08\x80\xf4\x03\x12\x0c(8) 32-64 ms\x12\x13\x08\x80\xe8\x07\x12\r(9) 64-128 ms\x12\x15\x08\x80\xd0\x0f\x12\x0f(10) 128-256 ms\x12\x15\x08\x80\xa0\x1f\x12\x0f(11) 256-512 ms\x12\x16\x08\x80\xc0>\x12\x10(12) 512-1024 ms\x12\x17\x08\x80\x89z\x12\x11(13) 1024-2000 ms\x12\x11\x08\x80\x92\xf4\x01\x12\n(14) 2-4 s\x12\x11\x08\x80\xa4\xe8\x03\x12\n(15) 4-8 s\x12\x12\x08\x80\xc8\xd0\x07\x12\x0b(16) 8-16 s\x12\x13\x08\x80\x90\xa1\x0f\x12\x0c(17) 16-32 s*\xbd!\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12#\n\x0eTXTYPE_READSET\x10\x01\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxReadSet\x12&\n\x10TXTYPE_PLAN_STEP\x10\x02\x1a\x10\x8a\xd6\x1b\x0c\n\nTxPlanStep\x12,\n\x13TXTYPE_PROPOSE_DATA\x10\x03\x1a\x13\x8a\xd6\x1b\x0f\n\rTxProposeData\x12\x30\n\x15TXTYPE_PROPOSE_SCHEME\x10\x04\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxProposeScheme\x12\x30\n\x15TXTYPE_PROGRESS_START\x10\x05\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxProgressStart\x12.\n\x14TXTYPE_PROGRESS_WAIT\x10\x06\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxProgressWait\x12\x36\n\x18TXTYPE_PROGRESS_COMPLETE\x10\x07\x1a\x18\x8a\xd6\x1b\x14\n\x12TxProgressComplete\x12\x31\n\x16TXTYPE_GET_STARD_STATE\x10\x08\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxGetShardState\x12\x37\n\x19TXTYPE_PROGRESS_RESEND_RS\x10\t\x1a\x18\x8a\xd6\x1b\x14\n\x12TxProgressResendRS\x12\x37\n\x19TXTYPE_CANCEL_TX_PROPOSAL\x10\n\x1a\x18\x8a\xd6\x1b\x14\n\x12TxCancelTxProposal\x12.\n\x14TXTYPE_CANCEL_BACKUP\x10\x0b\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxCancelBackup\x12)\n\x11TXTYPE_MONITORING\x10\x0c\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonitoring\x12\x30\n\x15TXTYPE_SCHEMA_CHANGED\x10\r\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxSchemaChanged\x12J\n#TXTYPE_INIT_SPLIT_MERGE_DESTINATION\x10\x0e\x1a!\x8a\xd6\x1b\x1d\n\x1bTxInitSplitMergeDestination\x12\x41\n\x1eTXTYPE_SPLIT_TRANSFER_SNAPSHOT\x10\x0f\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxSplitTransferSnapshot\x12\x31\n\x16TXTYPE_GET_TABLE_STATS\x10\x10\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxGetTableStats\x12N\n%TXTYPE_INITIATE_BORROWED_PARTS_RETURN\x10\x11\x1a#\x8a\xd6\x1b\x1f\n\x1dTxInitiateBorrowedPartsReturn\x12;\n\x1bTXTYPE_RETURN_BORROWED_PART\x10\x12\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxReturnBorrowedPart\x12\x42\n\x1fTXTYPE_RETURN_BORROWED_PART_ACK\x10\x13\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxReturnBorrowedPartAck\x12(\n\x11TXTYPE_GO_OFFLINE\x10\x14\x1a\x11\x8a\xd6\x1b\r\n\x0bTxGoOffline\x12\x1f\n\x0cTXTYPE_SPLIT\x10\x15\x1a\r\x8a\xd6\x1b\t\n\x07TxSplit\x12*\n\x12TXTYPE_START_SPLIT\x10\x16\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxStartSplit\x12@\n\x1dTXTYPE_SPLIT_SNASHOT_COMPLETE\x10\x17\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxSplitSnapshotComplete\x12\x43\n\"TXTYPE_SPLIT_TRANSFER_SNAPSHOT_ACK\x10\x18\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxTransferSnapshotAck\x12G\n!TXTYPE_SPLIT_PARTITIONING_CHANGED\x10\x19\x1a \x8a\xd6\x1b\x1c\n\x1aTxSplitPartitioningChanged\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x1a\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12J\n#TXTYPE_COPY_TABLE_SNAPSHOT_COMPLETE\x10\x1b\x1a!\x8a\xd6\x1b\x1d\n\x1bTxCopyTableSnapshotComplete\x12\x37\n\x19TXTYPE_FULL_SCAN_COMPLETE\x10\x1c\x1a\x18\x8a\xd6\x1b\x14\n\x12TxFullScanComplete\x12=\n\x1cTXTYPE_STREAM_RESPONSE_QUOTA\x10\x1d\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxStreamResponseQuota\x12+\n\x12TXTYPE_UNDELIVERED\x10\x1e\x1a\x13\x8a\xd6\x1b\x0f\n\rTxUndelivered\x12-\n\x13TXTYPE_DISCONNECTED\x10\x1f\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxDisconnected\x12(\n\x11TXTYPE_S3_LISTING\x10 \x1a\x11\x8a\xd6\x1b\r\n\x0bTxS3Listing\x12>\n\x1cTXTYPE_INITIATE_STATS_UPDATE\x10!\x1a\x1c\x8a\xd6\x1b\x18\n\x16TTxInitiateStatsUpdate\x12\x37\n\x19TXTYPE_CHECK_IN_READ_SETS\x10\"\x1a\x18\x8a\xd6\x1b\x14\n\x12TTxCheckInReadSets\x12@\n\x1eTXTYPE_REMOVE_OLD_IN_READ_SETS\x10#\x1a\x1c\x8a\xd6\x1b\x18\n\x16TTxRemoveOldInReadSets\x12+\n\x12TXTYPE_UPLOAD_ROWS\x10$\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxUploadRows\x12\x34\n\x17TXTYPE_STORE_TABLE_PATH\x10%\x1a\x17\x8a\xd6\x1b\x13\n\x11TTxStoreTablePath\x12-\n\x13TXTYPE_READ_COLUMNS\x10&\x1a\x14\x8a\xd6\x1b\x10\n\x0eTTxReadColumns\x12#\n\x0eTXTYPE_PROPOSE\x10\'\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxPropose\x12\x33\n\x17TXTYPE_STORE_SCAN_STATE\x10(\x1a\x16\x8a\xd6\x1b\x12\n\x10TxStoreScanState\x12;\n\x1bTXTYPE_INIT_SCHEMA_DEFAULTS\x10)\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxInitSchemaDefaults\x12\x45\n TXTYPE_REFRESH_VOLATILE_SNAPSHOT\x10*\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxRefreshVolatileSnapshot\x12\x45\n TXTYPE_DISCARD_VOLATILE_SNAPSHOT\x10+\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxDiscardVolatileSnapshot\x12\x45\n TXTYPE_CLEANUP_REMOVED_SNAPSHOTS\x10,\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxCleanupRemovedSnapshots\x12:\n\x1aTXTYPE_MIGRATE_SCHEMESHARD\x10-\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxMigrateSchemeShard\x12\x32\n\x17TXTYPE_GET_S3_UPLOAD_ID\x10.\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxGetS3UploadId\x12\x36\n\x19TXTYPE_STORE_S3_UPLOAD_ID\x10/\x1a\x17\x8a\xd6\x1b\x13\n\x11TxStoreS3UploadId\x12(\n\x11TXTYPE_ERASE_ROWS\x10\x30\x1a\x11\x8a\xd6\x1b\r\n\x0bTxEraseRows\x12\x46\n!TXTYPE_RELEASE_SNAPSHOT_REFERENCE\x10\x31\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxReleaseSnaphotReference\x12(\n\x11TXTYPE_STOP_GUARD\x10\x32\x1a\x11\x8a\xd6\x1b\r\n\x0bTxStopGuard\x12:\n\x1bTXTYPE_GET_S3_DOWNLOAD_INFO\x10\x33\x1a\x19\x8a\xd6\x1b\x15\n\x13TxGetS3DownloadInfo\x12>\n\x1dTXTYPE_STORE_S3_DOWNLOAD_INFO\x10\x34\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxStoreS3DownloadInfo\x12\x37\n\x19TXTYPE_UNSAFE_UPLOAD_ROWS\x10\x35\x1a\x18\x8a\xd6\x1b\x14\n\x12TxUnsafeUploadRows\x12\x44\n TXTYPE_PERSIST_SUBDOMAIN_PATH_ID\x10\x36\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxPersistSubDomainPathId\x12M\n%TXTYPE_PERSIST_SUBDOMAIN_OUT_OF_SPACE\x10\x37\x1a\"\x8a\xd6\x1b\x1e\n\x1cTxPersistSubDomainOutOfSpace\x12?\n\x1dTXTYPE_REQUEST_CHANGE_RECORDS\x10\x38\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxRequestChangeRecords\x12=\n\x1cTXTYPE_REMOVE_CHANGE_RECORDS\x10\x39\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxRemoveChangeRecords\x12\x45\n TXTYPE_CHANGE_EXCHANGE_HANDSHAKE\x10:\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxChangeExchangeHandshake\x12;\n\x1bTXTYPE_APPLY_CHANGE_RECORDS\x10;\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxApplyChangeRecords\x12\x44\n TXTYPE_EXECUTE_MVCC_STATE_CHANGE\x10<\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxExecuteMvccStateChange\x12@\n\x1eTXTYPE_CHANGE_S3_UPLOAD_STATUS\x10=\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxChangeS3UploadStatus\x12?\n\x1dTXTYPE_ACTIVATE_CHANGE_SENDER\x10>\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxActivateChangeSender\x12\x46\n!TXTYPE_ACTIVATE_CHANGE_SENDER_ACK\x10?\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxActivateChangeSenderAck\x12#\n\x0eTXTYPE_CLEANUP\x10@\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxCleanup\x12\x34\n\x17TXTYPE_COMPACT_BORROWED\x10\x41\x1a\x17\x8a\xd6\x1b\x13\n\x11TxCompactBorrowed\x12.\n\x14TXTYPE_COMPACT_TABLE\x10\x42\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxCompactTable\x12\x44\n TXTYPE_CHANGE_EXCHANGE_SPLIT_ACK\x10\x43\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxChangeExchangeSplitAck\x12\x45\n TXTYPE_APPLY_REPLICATION_CHANGES\x10\x44\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxApplyReplicationChanges\x12\x1d\n\x0bTXTYPE_READ\x10\x45\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxRead\x12R\n\'TXTYPE_SPLIT_REPLICATION_SOURCE_OFFSETS\x10\x46\x1a%\x8a\xd6\x1b!\n\x1fTxSplitReplicationSourceOffsets\x12*\n\x12TXTYPE_REMOVE_LOCK\x10G\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxRemoveLock\x12\x46\n!TXTYPE_REMOVE_LOCK_CHANGE_RECORDS\x10H\x1a\x1f\x8a\xd6\x1b\x1b\n\x19TxRemoveLockChangeRecords\x12\x37\n\x19TXTYPE_VOLATILE_TX_COMMIT\x10I\x1a\x18\x8a\xd6\x1b\x14\n\x12TxVolatileTxCommit\x12\x35\n\x18TXTYPE_VOLATILE_TX_ABORT\x10J\x1a\x17\x8a\xd6\x1b\x13\n\x11TxVolatileTxAbortB%\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\tDataShard')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_datashard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\tDataShard'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TX_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TX_IN_FLY"]._serialized_options = b'\202\326\033\t\n\007TxInFly'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STATE_WORK"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STATE_WORK"]._serialized_options = b'\202\326\033\013\n\tStateWork'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TX_COMPLETE_LAG"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TX_COMPLETE_LAG"]._serialized_options = b'\202\326\033\017\n\rTxCompleteLag'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_OUT_READSETS_IN_FLIGHT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_OUT_READSETS_IN_FLIGHT"]._serialized_options = b'\202\326\033\025\n\023OutReadSetsInFlight'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IMMEDIATE_TX_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IMMEDIATE_TX_IN_FLY"]._serialized_options = b'\202\326\033\022\n\020ImmediateTxInFly'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IMMEDIATE_TX_DELAYED"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IMMEDIATE_TX_DELAYED"]._serialized_options = b'\202\326\033\024\n\022ImmediateTxDelayed'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SCAN_TX_COMPLETE_LAG"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SCAN_TX_COMPLETE_LAG"]._serialized_options = b'\202\326\033\023\n\021ScanTxCompleteLag'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PROPOSE_QUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PROPOSE_QUEUE_SIZE"]._serialized_options = b'\202\326\033\022\n\020ProposeQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_SRC_WAIT_TX_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_SRC_WAIT_TX_IN_FLY"]._serialized_options = b'\202\326\033\025\n\023SplitSrcWaitTxInFly'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_SRC_WAIT_IMMEDIATE_TX_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_SRC_WAIT_IMMEDIATE_TX_IN_FLY"]._serialized_options = b'\202\326\033\036\n\034SplitSrcWaitImmediateTxInFly'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MVCC_STATE_CHANGE_WAIT_TX_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MVCC_STATE_CHANGE_WAIT_TX_IN_FLY"]._serialized_options = b'\202\326\033\034\n\032MvccStateChangeWaitTxInFly'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MVCC_STATE_CHANGE_WAIT_IMMEDIATE_TX_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MVCC_STATE_CHANGE_WAIT_IMMEDIATE_TX_IN_FLY"]._serialized_options = b'\202\326\033%\n#MvccStateChangeWaitImmediateTxInFly'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MVCC_ENABLED"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MVCC_ENABLED"]._serialized_options = b'\202\326\033\r\n\013MvccEnabled'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_CHANGE_QUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_CHANGE_QUEUE_SIZE"]._serialized_options = b'\202\326\033\021\n\017ChangeQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_READ_ITERATORS_WAITING"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_READ_ITERATORS_WAITING"]._serialized_options = b'\202\326\033\026\n\024ReadIteratorsWaiting'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_READ_ITERATORS_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_READ_ITERATORS_COUNT"]._serialized_options = b'\202\326\033\024\n\022ReadIteratorsCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQ_RO"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQ_RO"]._serialized_options = b'\202\326\033\007\n\005ReqRo'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_REQUEST"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_REQUEST"]._serialized_options = b'\202\326\033\021\n\017PrepareRequests'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_ERROR"]._serialized_options = b'\202\326\033\017\n\rPrepareErrors'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_IMMEDIATE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_IMMEDIATE"]._serialized_options = b'\202\326\033\022\n\020PrepareImmediate'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_SUCCESS"]._serialized_options = b'\202\326\033\020\n\016PrepareSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_COMPLETE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_COMPLETE"]._serialized_options = b'\202\326\033\021\n\017PrepareComplete'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_DIRTY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_DIRTY"]._serialized_options = b'\202\326\033\016\n\014PrepareDirty'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_OVERLOADED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_OVERLOADED"]._serialized_options = b'\202\326\033\023\n\021PrepareOverloaded'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_IGNORED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_IGNORED"]._serialized_options = b'\202\326\033\021\n\017PlanStepIgnored'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_ACCEPTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_ACCEPTED"]._serialized_options = b'\202\326\033\022\n\020PlanStepAccepted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_SHARD_INACTIVE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_SHARD_INACTIVE"]._serialized_options = b'\202\326\033\031\n\027TxProgressShardInactive'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_QUEUE_EMPTY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_QUEUE_EMPTY"]._serialized_options = b'\202\326\033\026\n\024TxProgressQueueEmpty'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_CLEANUP"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_CLEANUP"]._serialized_options = b'\202\326\033\023\n\021TxProgressCleanup'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_OUTDATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_OUTDATED"]._serialized_options = b'\202\326\033\024\n\022TxProgressOutdated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_DUPLICATE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_DUPLICATE"]._serialized_options = b'\202\326\033\025\n\023TxProgressDuplicate'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_DIRTY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_DIRTY"]._serialized_options = b'\202\326\033\021\n\017TxProgressDirty'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_EV"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_EV"]._serialized_options = b'\202\326\033\022\n\020TxProgressEvents'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_CLEANUP_SCHEDULED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_CLEANUP_SCHEDULED"]._serialized_options = b'\202\326\033\024\n\022TxCleanupScheduled'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_IDLE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_IDLE"]._serialized_options = b'\202\326\033\020\n\016TxProgressIdle'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ACK_SENT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ACK_SENT"]._serialized_options = b'\202\326\033\t\n\007AckSent'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ACK_SENT_DELAYED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ACK_SENT_DELAYED"]._serialized_options = b'\202\326\033\020\n\016AckSentDelayed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CANCEL_TX_NOTFOUND"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CANCEL_TX_NOTFOUND"]._serialized_options = b'\202\326\033\022\n\020CancelTxNotFound'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_MINIKQL_PROGRAM_SIZE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_MINIKQL_PROGRAM_SIZE"]._serialized_options = b'\202\326\033\024\n\022MiniKQLProgramSize'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_ROW"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_ROW"]._serialized_options = b'\202\326\033\024\n\022EngineHostRowReads'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_RANGE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_RANGE"]._serialized_options = b'\202\326\033\026\n\024EngineHostRangeReads'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_UPDATE_ROW"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_UPDATE_ROW"]._serialized_options = b'\202\326\033\026\n\024EngineHostRowUpdates'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_ERASE_ROW"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_ERASE_ROW"]._serialized_options = b'\202\326\033\025\n\023EngineHostRowErases'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_CANCELLED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_CANCELLED"]._serialized_options = b'\202\326\033\022\n\020PrepareCancelled'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READSET_SENT_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READSET_SENT_COUNT"]._serialized_options = b'\202\326\033\022\n\020ReadsetSentCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READSET_SENT_SIZE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READSET_SENT_SIZE"]._serialized_options = b'\202\326\033\021\n\017ReadsetSentSize'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READSET_RECEIVED_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READSET_RECEIVED_COUNT"]._serialized_options = b'\202\326\033\026\n\024ReadsetReceivedCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READSET_RECEIVED_SIZE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READSET_RECEIVED_SIZE"]._serialized_options = b'\202\326\033\025\n\023ReadsetReceivedSize'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_RESULT_SIZE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_RESULT_SIZE"]._serialized_options = b'\202\326\033\016\n\014TxResultSize'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_REJECTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_REJECTED"]._serialized_options = b'\202\326\033\017\n\rLocksRejected'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_ACQUIRED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_ACQUIRED"]._serialized_options = b'\202\326\033\017\n\rLocksAcquired'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_EVICTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_EVICTED"]._serialized_options = b'\202\326\033\016\n\014LocksEvicted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_BROKEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_BROKEN"]._serialized_options = b'\202\326\033\r\n\013LocksBroken'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_ERASED"]._serialized_options = b'\202\326\033\r\n\013LocksErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_REMOVED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_REMOVED"]._serialized_options = b'\202\326\033\016\n\014LocksRemoved'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_REJECT_BROKEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_REJECT_BROKEN"]._serialized_options = b'\202\326\033\023\n\021LocksRejectBroken'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_LOST"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_LOST"]._serialized_options = b'\202\326\033\013\n\tLocksLost'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INACTIVE_TX_DATA_RELEASES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INACTIVE_TX_DATA_RELEASES"]._serialized_options = b'\202\326\033\030\n\026InactiveTxDataReleases'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PIPELINE_OVERLOADED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PIPELINE_OVERLOADED"]._serialized_options = b'\202\326\033\024\n\022PipelineOverloaded'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_DELAYED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_DELAYED"]._serialized_options = b'\202\326\033\023\n\021TxProgressDelayed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_REORDERED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_REORDERED"]._serialized_options = b'\202\326\033\r\n\013TxReordered'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_WAIT_ORDER"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_WAIT_ORDER"]._serialized_options = b'\202\326\033\021\n\017TxCannotReorder'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_WAIT_DATA"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_WAIT_DATA"]._serialized_options = b'\202\326\033\014\n\nTxWaitData'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_WAIT_READ_SETS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_WAIT_READ_SETS"]._serialized_options = b'\202\326\033\020\n\016TxWaitReadSets'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_WAIT_RESOURCE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_WAIT_RESOURCE"]._serialized_options = b'\202\326\033\020\n\016TxWaitResource'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_WHOLE_SHARD"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_LOCKS_WHOLE_SHARD"]._serialized_options = b'\202\326\033\021\n\017LocksWholeShard'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_ROW_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_ROW_BYTES"]._serialized_options = b'\202\326\033\030\n\026EngineHostRowReadBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_RANGE_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_RANGE_ROWS"]._serialized_options = b'\202\326\033\031\n\027EngineHostRangeReadRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_RANGE_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_RANGE_BYTES"]._serialized_options = b'\202\326\033\032\n\030EngineHostRangeReadBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_UPDATE_ROW_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_UPDATE_ROW_BYTES"]._serialized_options = b'\202\326\033\032\n\030EngineHostRowUpdateBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_ERASE_ROW_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_ERASE_ROW_BYTES"]._serialized_options = b'\202\326\033\031\n\027EngineHostRowEraseBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLANNED_TX_COMPLETE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLANNED_TX_COMPLETE"]._serialized_options = b'\202\326\033\023\n\021PlannedTxComplete'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_OUT_OF_SPACE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_OUT_OF_SPACE"]._serialized_options = b'\202\326\033\023\n\021PrepareOutOfSpace'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_IMMEDIATE_TX_CANCELLED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_IMMEDIATE_TX_CANCELLED"]._serialized_options = b'\202\326\033\026\n\024ImmediateTxCancelled'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLANNED_TX_CANCELLED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLANNED_TX_CANCELLED"]._serialized_options = b'\202\326\033\024\n\022PlannedTxCancelled'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPLOAD_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPLOAD_ROWS"]._serialized_options = b'\202\326\033\014\n\nUploadRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPLOAD_ROWS_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPLOAD_ROWS_BYTES"]._serialized_options = b'\202\326\033\021\n\017UploadRowsBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_RANGE_ROW_SKIPS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ENGINE_HOST_SELECT_RANGE_ROW_SKIPS"]._serialized_options = b'\202\326\033$\n\"EngineHostRangeReadDeletedRowSkips'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_COLUMNS_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_COLUMNS_ROWS"]._serialized_options = b'\202\326\033\021\n\017ReadColumnsRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_COLUMNS_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_COLUMNS_BYTES"]._serialized_options = b'\202\326\033\022\n\020ReadColumnsBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_ROWS"]._serialized_options = b'\202\326\033\r\n\013ScannedRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_BYTES"]._serialized_options = b'\202\326\033\016\n\014ScannedBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PROPOSE_QUEUE_EV"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PROPOSE_QUEUE_EV"]._serialized_options = b'\202\326\033\026\n\024TxProposeQueueEvents'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BULK_UPSERT_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BULK_UPSERT_SUCCESS"]._serialized_options = b'\202\326\033\023\n\021BulkUpsertSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BULK_UPSERT_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BULK_UPSERT_ERROR"]._serialized_options = b'\202\326\033\021\n\017BulkUpsertError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BULK_UPSERT_OVERLOADED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BULK_UPSERT_OVERLOADED"]._serialized_options = b'\202\326\033\026\n\024BulkUpsertOverloaded'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ERASE_ROWS_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ERASE_ROWS_SUCCESS"]._serialized_options = b'\202\326\033\022\n\020EraseRowsSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ERASE_ROWS_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ERASE_ROWS_ERROR"]._serialized_options = b'\202\326\033\020\n\016EraseRowsError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ERASE_ROWS_OVERLOADED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ERASE_ROWS_OVERLOADED"]._serialized_options = b'\202\326\033\025\n\023EraseRowsOverloaded'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ERASE_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ERASE_ROWS"]._serialized_options = b'\202\326\033\013\n\tEraseRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BUILD_DEPENDENCIES_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BUILD_DEPENDENCIES_USEC"]._serialized_options = b'\202\326\033\033\n\031BuildDependenciesMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_APPLY_LOCKS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_APPLY_LOCKS_USEC"]._serialized_options = b'\202\326\033\024\n\022ApplyLocksMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_NOT_ENOUGH_MEMORY_1"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_NOT_ENOUGH_MEMORY_1"]._serialized_options = b'\202\326\033\024\n\022TxNotEnoughMemory1'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_NOT_ENOUGH_MEMORY_2"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_NOT_ENOUGH_MEMORY_2"]._serialized_options = b'\202\326\033\024\n\022TxNotEnoughMemory2'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_NOT_ENOUGH_MEMORY_3"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_NOT_ENOUGH_MEMORY_3"]._serialized_options = b'\202\326\033\024\n\022TxNotEnoughMemory3'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_NOT_ENOUGH_MEMORY_4"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_NOT_ENOUGH_MEMORY_4"]._serialized_options = b'\202\326\033\024\n\022TxNotEnoughMemory4'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_TABLET_NOT_READY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_TABLET_NOT_READY"]._serialized_options = b'\202\326\033\022\n\020TxTabletNotReady'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION"]._serialized_options = b'\202\326\033\020\n\016TxCompactTable'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION_NOT_NEEDED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION_NOT_NEEDED"]._serialized_options = b'\202\326\033\031\n\027TxCompactTableNotNeeded'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION_FAILED_BORROWED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION_FAILED_BORROWED"]._serialized_options = b'\202\326\033\036\n\034TxCompactTableFailedBorrowed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION_FAILED_START"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION_FAILED_START"]._serialized_options = b'\202\326\033\033\n\031TxCompactTableFailedStart'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FULL_COMPACTION_DONE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FULL_COMPACTION_DONE"]._serialized_options = b'\202\326\033\025\n\023FullCompactionCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION_FAILED_LOANED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_BACKGROUND_COMPACTION_FAILED_LOANED"]._serialized_options = b'\202\326\033\034\n\032TxCompactTableFailedLoaned'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_COMPACT_BORROWED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TX_COMPACT_BORROWED"]._serialized_options = b'\202\326\033\023\n\021TxCompactBorrowed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CHANGE_RECORDS_ENQUEUED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CHANGE_RECORDS_ENQUEUED"]._serialized_options = b'\202\326\033\027\n\025ChangeRecordsEnqueued'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CHANGE_RECORDS_REMOVED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CHANGE_RECORDS_REMOVED"]._serialized_options = b'\202\326\033\026\n\024ChangeRecordsRemoved'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_NO_QUOTA"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_NO_QUOTA"]._serialized_options = b'\202\326\033\025\n\023ReadIteratorNoQuota'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_MAX_ROWS_REACHED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_MAX_ROWS_REACHED"]._serialized_options = b'\202\326\033\034\n\032ReadIteratorMaxRowsReached'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_MAX_TIME_REACHED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_MAX_TIME_REACHED"]._serialized_options = b'\202\326\033\034\n\032ReadIteratorMaxTimeReached'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_ROWS_READ"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_ROWS_READ"]._serialized_options = b'\202\326\033\026\n\024ReadIteratorRowsRead'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_BYTES_READ"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_BYTES_READ"]._serialized_options = b'\202\326\033\027\n\025ReadIteratorBytesRead'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_CANCEL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_CANCEL"]._serialized_options = b'\202\326\033\024\n\022ReadIteratorCancel'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\326\002\022\021\010\364\003\022\014(1) < 500 us\022\021\010\350\007\022\014(2) 0.5-1 ms\022\017\010\320\017\022\n(3) 1-2 ms\022\017\010\240\037\022\n(4) 2-4 ms\022\017\010\300>\022\n(5) 4-8 ms\022\020\010\200}\022\013(6) 8-16 ms\022\022\010\200\372\001\022\014(7) 16-32 ms\022\022\010\200\364\003\022\014(8) 32-64 ms\022\023\010\200\350\007\022\r(9) 64-128 ms\022\025\010\200\320\017\022\017(10) 128-256 ms\022\025\010\200\240\037\022\017(11) 256-512 ms\022\026\010\200\300>\022\020(12) 512-1024 ms\022\027\010\200\211z\022\021(13) 1024-2000 ms\022\021\010\200\222\364\001\022\n(14) 2-4 s\022\021\010\200\244\350\003\022\n(15) 4-8 s\022\022\010\200\310\320\007\022\013(16) 8-16 s\022\023\010\200\220\241\017\022\014(17) 16-32 s'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PREPARE_SUCCESS_COMPLETE_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PREPARE_SUCCESS_COMPLETE_LATENCY"]._serialized_options = b'\202\326\033\037\n\035PrepareSuccessCompleteLatency'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_ACCEPTED_PLAN_STEP_COMPLETE_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_ACCEPTED_PLAN_STEP_COMPLETE_LATENCY"]._serialized_options = b'\202\326\033!\n\037AcceptedPlanStepCompleteLatency'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_COMPLETE_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_COMPLETE_LATENCY"]._serialized_options = b'\202\326\033\033\n\031TxProgressCompleteLatency'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PLAN_TO_EXECUTE_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PLAN_TO_EXECUTE_LATENCY"]._serialized_options = b'\202\326\033\026\n\024PlanToExecuteLatency'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PREPARE_EXEC_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PREPARE_EXEC_LATENCY"]._serialized_options = b'\202\326\033\024\n\022PrepareExecLatency'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_EXEC_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_TX_PROGRESS_EXEC_LATENCY"]._serialized_options = b'\202\326\033\027\n\025TxProgressExecLatency'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LOCKS_ACTIVE_PER_SHARD"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LOCKS_ACTIVE_PER_SHARD"]._serialized_options = b'\202\326\033\222\001\n\023LocksActivePerShard\022\005\010\000\022\0010\022\010\010\n\022\0041-10\022\n\010d\022\00610-100\022\014\010\364\003\022\007100-500\022\r\010\350\007\022\010500-1000\022\016\010\240\037\022\t1000-4000\022\016\010\300>\022\t4000-8000\022\017\010\340]\022\n8000-12000\022\020\010\200}\022\01312000-16000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LOCKS_BROKEN_PER_SHARD"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LOCKS_BROKEN_PER_SHARD"]._serialized_options = b'\202\326\033\222\001\n\023LocksBrokenPerShard\022\005\010\000\022\0010\022\010\010\n\022\0041-10\022\n\010d\022\00610-100\022\014\010\364\003\022\007100-500\022\r\010\350\007\022\010500-1000\022\016\010\240\037\022\t1000-4000\022\016\010\300>\022\t4000-8000\022\017\010\340]\022\n8000-12000\022\020\010\200}\022\01312000-16000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LOCKS_LIFETIME"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LOCKS_LIFETIME"]._serialized_options = b'\202\326\033\017\n\rLocksLifetime'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PROPOSE_QUEUE_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PROPOSE_QUEUE_LATENCY"]._serialized_options = b'\202\326\033\025\n\023ProposeQueueLatency'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_HIST_RANGE_READ_BYTES"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_HIST_RANGE_READ_BYTES"]._serialized_options = b'\202\326\033\262\002\n(HIST(DataShard/EngineHostRangeReadBytes)\022\005\010\000\022\0010\022\t\010\200\010\022\0041024\022\t\010\200\020\022\0042048\022\t\010\200 \022\0044096\022\t\010\200@\022\0048192\022\013\010\200\200\001\022\00516384\022\013\010\200\200\002\022\00532768\022\013\010\200\200\004\022\00565536\022\014\010\200\200\010\022\006131072\022\014\010\200\200\020\022\006262144\022\014\010\200\200 \022\006524288\022\r\010\200\200@\022\0071048576\022\016\010\200\200\200\001\022\0072097152\022\016\010\200\200\200\002\022\0074194304\022\016\010\200\200\200\004\022\0078388608\022\017\010\200\200\200\010\022\01016777216\022\017\010\200\200\200\020\022\01033554432\022\017\010\200\200\200 \022\01067108864\022\020\010\200\200\200@\022\t134217728'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SELECT_ROWS_PER_REQUEST"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SELECT_ROWS_PER_REQUEST"]._serialized_options = b'\202\326\033Z\n\024SelectRowsPerRequest\022\005\010\000\022\0010\022\005\010\001\022\0011\022\006\010\n\022\00210\022\007\010d\022\003100\022\t\010\350\007\022\0041000\022\n\010\220N\022\00510000\022\014\010\240\215\006\022\006100000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_RANGE_READ_ROWS_PER_REQUEST"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_RANGE_READ_ROWS_PER_REQUEST"]._serialized_options = b'\202\326\033]\n\027RangeReadRowsPerRequest\022\005\010\000\022\0010\022\005\010\001\022\0011\022\006\010\n\022\00210\022\007\010d\022\003100\022\t\010\350\007\022\0041000\022\n\010\220N\022\00510000\022\014\010\240\215\006\022\006100000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PLAN_QUEUE_LATENCY_MS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PLAN_QUEUE_LATENCY_MS"]._serialized_options = b'\202\326\033\253\001\n\022PlanQueueLatencyMs\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\002\022\0012\022\005\010\005\022\0015\022\006\010\n\022\00210\022\006\010\031\022\00225\022\006\0102\022\00250\022\007\010}\022\003125\022\010\010\372\001\022\003250\022\010\010\364\003\022\003500\022\t\010\350\007\022\0041000\022\t\010\320\017\022\0042000\022\t\010\210\'\022\0045000\022\n\010\220N\022\00510000\022\n\010\230u\022\00515000\022\013\010\260\352\001\022\00530000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_WAIT_DEPENDENCIES_LATENCY_MS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_WAIT_DEPENDENCIES_LATENCY_MS"]._serialized_options = b'\202\326\033\262\001\n\031WaitDependenciesLatencyMs\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\002\022\0012\022\005\010\005\022\0015\022\006\010\n\022\00210\022\006\010\031\022\00225\022\006\0102\022\00250\022\007\010}\022\003125\022\010\010\372\001\022\003250\022\010\010\364\003\022\003500\022\t\010\350\007\022\0041000\022\t\010\320\017\022\0042000\022\t\010\210\'\022\0045000\022\n\010\220N\022\00510000\022\n\010\230u\022\00515000\022\013\010\260\352\001\022\00530000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_WAIT_READSETS_LATENCY_MS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_WAIT_READSETS_LATENCY_MS"]._serialized_options = b'\202\326\033\256\001\n\025WaitReadSetsLatencyMs\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\002\022\0012\022\005\010\005\022\0015\022\006\010\n\022\00210\022\006\010\031\022\00225\022\006\0102\022\00250\022\007\010}\022\003125\022\010\010\372\001\022\003250\022\010\010\364\003\022\003500\022\t\010\350\007\022\0041000\022\t\010\320\017\022\0042000\022\t\010\210\'\022\0045000\022\n\010\220N\022\00510000\022\n\010\230u\022\00515000\022\013\010\260\352\001\022\00530000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_WAIT_EXECUTE_LATENCY_MS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_WAIT_EXECUTE_LATENCY_MS"]._serialized_options = b'\202\326\033\255\001\n\024WaitExecuteLatencyMs\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\002\022\0012\022\005\010\005\022\0015\022\006\010\n\022\00210\022\006\010\031\022\00225\022\006\0102\022\00250\022\007\010}\022\003125\022\010\010\372\001\022\003250\022\010\010\364\003\022\003500\022\t\010\350\007\022\0041000\022\t\010\320\017\022\0042000\022\t\010\210\'\022\0045000\022\n\010\220N\022\00510000\022\n\010\230u\022\00515000\022\013\010\260\352\001\022\00530000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_WAIT_TOTAL_LATENCY_MS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_WAIT_TOTAL_LATENCY_MS"]._serialized_options = b'\202\326\033\253\001\n\022WaitTotalLatencyMs\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\002\022\0012\022\005\010\005\022\0015\022\006\010\n\022\00210\022\006\010\031\022\00225\022\006\0102\022\00250\022\007\010}\022\003125\022\010\010\372\001\022\003250\022\010\010\364\003\022\003500\022\t\010\350\007\022\0041000\022\t\010\320\017\022\0042000\022\t\010\210\'\022\0045000\022\n\010\220N\022\00510000\022\n\010\230u\022\00515000\022\013\010\260\352\001\022\00530000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_LIFETIME_MS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_LIFETIME_MS"]._serialized_options = b'\202\326\033t\n\026ReadIteratorLifetimeMs\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\002\022\0012\022\005\010\005\022\0015\022\006\010\n\022\00210\022\006\010\031\022\00225\022\006\0102\022\00250\022\007\010}\022\003125\022\010\010\372\001\022\003250\022\010\010\364\003\022\003500\022\t\010\350\007\022\0041000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_ITERATION_LATENCY_MS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_READ_ITERATOR_ITERATION_LATENCY_MS"]._serialized_options = b'\202\326\033D\n\036ReadIteratorIterationLatencyMs\022\005\010\000\022\0010\022\005\010\001\022\0011\022\005\010\002\022\0012\022\005\010\005\022\0015\022\006\010\n\022\00210'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_READSET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_READSET"]._serialized_options = b'\212\326\033\013\n\tTxReadSet'
  _ETXTYPES.values_by_name["TXTYPE_PLAN_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PLAN_STEP"]._serialized_options = b'\212\326\033\014\n\nTxPlanStep'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_DATA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_DATA"]._serialized_options = b'\212\326\033\017\n\rTxProposeData'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_SCHEME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_SCHEME"]._serialized_options = b'\212\326\033\021\n\017TxProposeScheme'
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_START"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_START"]._serialized_options = b'\212\326\033\021\n\017TxProgressStart'
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_WAIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_WAIT"]._serialized_options = b'\212\326\033\020\n\016TxProgressWait'
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_COMPLETE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_COMPLETE"]._serialized_options = b'\212\326\033\024\n\022TxProgressComplete'
  _ETXTYPES.values_by_name["TXTYPE_GET_STARD_STATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_STARD_STATE"]._serialized_options = b'\212\326\033\021\n\017TxGetShardState'
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_RESEND_RS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS_RESEND_RS"]._serialized_options = b'\212\326\033\024\n\022TxProgressResendRS'
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_TX_PROPOSAL"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_TX_PROPOSAL"]._serialized_options = b'\212\326\033\024\n\022TxCancelTxProposal'
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_BACKUP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CANCEL_BACKUP"]._serialized_options = b'\212\326\033\020\n\016TxCancelBackup'
  _ETXTYPES.values_by_name["TXTYPE_MONITORING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MONITORING"]._serialized_options = b'\212\326\033\016\n\014TxMonitoring'
  _ETXTYPES.values_by_name["TXTYPE_SCHEMA_CHANGED"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SCHEMA_CHANGED"]._serialized_options = b'\212\326\033\021\n\017TxSchemaChanged'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SPLIT_MERGE_DESTINATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SPLIT_MERGE_DESTINATION"]._serialized_options = b'\212\326\033\035\n\033TxInitSplitMergeDestination'
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_TRANSFER_SNAPSHOT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_TRANSFER_SNAPSHOT"]._serialized_options = b'\212\326\033\031\n\027TxSplitTransferSnapshot'
  _ETXTYPES.values_by_name["TXTYPE_GET_TABLE_STATS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_TABLE_STATS"]._serialized_options = b'\212\326\033\021\n\017TxGetTableStats'
  _ETXTYPES.values_by_name["TXTYPE_INITIATE_BORROWED_PARTS_RETURN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INITIATE_BORROWED_PARTS_RETURN"]._serialized_options = b'\212\326\033\037\n\035TxInitiateBorrowedPartsReturn'
  _ETXTYPES.values_by_name["TXTYPE_RETURN_BORROWED_PART"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RETURN_BORROWED_PART"]._serialized_options = b'\212\326\033\026\n\024TxReturnBorrowedPart'
  _ETXTYPES.values_by_name["TXTYPE_RETURN_BORROWED_PART_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RETURN_BORROWED_PART_ACK"]._serialized_options = b'\212\326\033\031\n\027TxReturnBorrowedPartAck'
  _ETXTYPES.values_by_name["TXTYPE_GO_OFFLINE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GO_OFFLINE"]._serialized_options = b'\212\326\033\r\n\013TxGoOffline'
  _ETXTYPES.values_by_name["TXTYPE_SPLIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SPLIT"]._serialized_options = b'\212\326\033\t\n\007TxSplit'
  _ETXTYPES.values_by_name["TXTYPE_START_SPLIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_START_SPLIT"]._serialized_options = b'\212\326\033\016\n\014TxStartSplit'
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_SNASHOT_COMPLETE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_SNASHOT_COMPLETE"]._serialized_options = b'\212\326\033\031\n\027TxSplitSnapshotComplete'
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_TRANSFER_SNAPSHOT_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_TRANSFER_SNAPSHOT_ACK"]._serialized_options = b'\212\326\033\027\n\025TxTransferSnapshotAck'
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_PARTITIONING_CHANGED"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_PARTITIONING_CHANGED"]._serialized_options = b'\212\326\033\034\n\032TxSplitPartitioningChanged'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_COPY_TABLE_SNAPSHOT_COMPLETE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COPY_TABLE_SNAPSHOT_COMPLETE"]._serialized_options = b'\212\326\033\035\n\033TxCopyTableSnapshotComplete'
  _ETXTYPES.values_by_name["TXTYPE_FULL_SCAN_COMPLETE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FULL_SCAN_COMPLETE"]._serialized_options = b'\212\326\033\024\n\022TxFullScanComplete'
  _ETXTYPES.values_by_name["TXTYPE_STREAM_RESPONSE_QUOTA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STREAM_RESPONSE_QUOTA"]._serialized_options = b'\212\326\033\027\n\025TxStreamResponseQuota'
  _ETXTYPES.values_by_name["TXTYPE_UNDELIVERED"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UNDELIVERED"]._serialized_options = b'\212\326\033\017\n\rTxUndelivered'
  _ETXTYPES.values_by_name["TXTYPE_DISCONNECTED"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DISCONNECTED"]._serialized_options = b'\212\326\033\020\n\016TxDisconnected'
  _ETXTYPES.values_by_name["TXTYPE_S3_LISTING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_S3_LISTING"]._serialized_options = b'\212\326\033\r\n\013TxS3Listing'
  _ETXTYPES.values_by_name["TXTYPE_INITIATE_STATS_UPDATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INITIATE_STATS_UPDATE"]._serialized_options = b'\212\326\033\030\n\026TTxInitiateStatsUpdate'
  _ETXTYPES.values_by_name["TXTYPE_CHECK_IN_READ_SETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CHECK_IN_READ_SETS"]._serialized_options = b'\212\326\033\024\n\022TTxCheckInReadSets'
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_OLD_IN_READ_SETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_OLD_IN_READ_SETS"]._serialized_options = b'\212\326\033\030\n\026TTxRemoveOldInReadSets'
  _ETXTYPES.values_by_name["TXTYPE_UPLOAD_ROWS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPLOAD_ROWS"]._serialized_options = b'\212\326\033\017\n\rTTxUploadRows'
  _ETXTYPES.values_by_name["TXTYPE_STORE_TABLE_PATH"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STORE_TABLE_PATH"]._serialized_options = b'\212\326\033\023\n\021TTxStoreTablePath'
  _ETXTYPES.values_by_name["TXTYPE_READ_COLUMNS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_READ_COLUMNS"]._serialized_options = b'\212\326\033\020\n\016TTxReadColumns'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE"]._serialized_options = b'\212\326\033\013\n\tTxPropose'
  _ETXTYPES.values_by_name["TXTYPE_STORE_SCAN_STATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STORE_SCAN_STATE"]._serialized_options = b'\212\326\033\022\n\020TxStoreScanState'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA_DEFAULTS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA_DEFAULTS"]._serialized_options = b'\212\326\033\026\n\024TxInitSchemaDefaults'
  _ETXTYPES.values_by_name["TXTYPE_REFRESH_VOLATILE_SNAPSHOT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REFRESH_VOLATILE_SNAPSHOT"]._serialized_options = b'\212\326\033\033\n\031TxRefreshVolatileSnapshot'
  _ETXTYPES.values_by_name["TXTYPE_DISCARD_VOLATILE_SNAPSHOT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DISCARD_VOLATILE_SNAPSHOT"]._serialized_options = b'\212\326\033\033\n\031TxDiscardVolatileSnapshot'
  _ETXTYPES.values_by_name["TXTYPE_CLEANUP_REMOVED_SNAPSHOTS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CLEANUP_REMOVED_SNAPSHOTS"]._serialized_options = b'\212\326\033\033\n\031TxCleanupRemovedSnapshots'
  _ETXTYPES.values_by_name["TXTYPE_MIGRATE_SCHEMESHARD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MIGRATE_SCHEMESHARD"]._serialized_options = b'\212\326\033\026\n\024TxMigrateSchemeShard'
  _ETXTYPES.values_by_name["TXTYPE_GET_S3_UPLOAD_ID"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_S3_UPLOAD_ID"]._serialized_options = b'\212\326\033\021\n\017TxGetS3UploadId'
  _ETXTYPES.values_by_name["TXTYPE_STORE_S3_UPLOAD_ID"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STORE_S3_UPLOAD_ID"]._serialized_options = b'\212\326\033\023\n\021TxStoreS3UploadId'
  _ETXTYPES.values_by_name["TXTYPE_ERASE_ROWS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ERASE_ROWS"]._serialized_options = b'\212\326\033\r\n\013TxEraseRows'
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_SNAPSHOT_REFERENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_SNAPSHOT_REFERENCE"]._serialized_options = b'\212\326\033\033\n\031TxReleaseSnaphotReference'
  _ETXTYPES.values_by_name["TXTYPE_STOP_GUARD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STOP_GUARD"]._serialized_options = b'\212\326\033\r\n\013TxStopGuard'
  _ETXTYPES.values_by_name["TXTYPE_GET_S3_DOWNLOAD_INFO"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_S3_DOWNLOAD_INFO"]._serialized_options = b'\212\326\033\025\n\023TxGetS3DownloadInfo'
  _ETXTYPES.values_by_name["TXTYPE_STORE_S3_DOWNLOAD_INFO"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STORE_S3_DOWNLOAD_INFO"]._serialized_options = b'\212\326\033\027\n\025TxStoreS3DownloadInfo'
  _ETXTYPES.values_by_name["TXTYPE_UNSAFE_UPLOAD_ROWS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UNSAFE_UPLOAD_ROWS"]._serialized_options = b'\212\326\033\024\n\022TxUnsafeUploadRows'
  _ETXTYPES.values_by_name["TXTYPE_PERSIST_SUBDOMAIN_PATH_ID"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PERSIST_SUBDOMAIN_PATH_ID"]._serialized_options = b'\212\326\033\032\n\030TxPersistSubDomainPathId'
  _ETXTYPES.values_by_name["TXTYPE_PERSIST_SUBDOMAIN_OUT_OF_SPACE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PERSIST_SUBDOMAIN_OUT_OF_SPACE"]._serialized_options = b'\212\326\033\036\n\034TxPersistSubDomainOutOfSpace'
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_CHANGE_RECORDS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_CHANGE_RECORDS"]._serialized_options = b'\212\326\033\030\n\026TxRequestChangeRecords'
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_CHANGE_RECORDS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_CHANGE_RECORDS"]._serialized_options = b'\212\326\033\027\n\025TxRemoveChangeRecords'
  _ETXTYPES.values_by_name["TXTYPE_CHANGE_EXCHANGE_HANDSHAKE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CHANGE_EXCHANGE_HANDSHAKE"]._serialized_options = b'\212\326\033\033\n\031TxChangeExchangeHandshake'
  _ETXTYPES.values_by_name["TXTYPE_APPLY_CHANGE_RECORDS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_APPLY_CHANGE_RECORDS"]._serialized_options = b'\212\326\033\026\n\024TxApplyChangeRecords'
  _ETXTYPES.values_by_name["TXTYPE_EXECUTE_MVCC_STATE_CHANGE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_EXECUTE_MVCC_STATE_CHANGE"]._serialized_options = b'\212\326\033\032\n\030TxExecuteMvccStateChange'
  _ETXTYPES.values_by_name["TXTYPE_CHANGE_S3_UPLOAD_STATUS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CHANGE_S3_UPLOAD_STATUS"]._serialized_options = b'\212\326\033\030\n\026TxChangeS3UploadStatus'
  _ETXTYPES.values_by_name["TXTYPE_ACTIVATE_CHANGE_SENDER"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ACTIVATE_CHANGE_SENDER"]._serialized_options = b'\212\326\033\030\n\026TxActivateChangeSender'
  _ETXTYPES.values_by_name["TXTYPE_ACTIVATE_CHANGE_SENDER_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ACTIVATE_CHANGE_SENDER_ACK"]._serialized_options = b'\212\326\033\033\n\031TxActivateChangeSenderAck'
  _ETXTYPES.values_by_name["TXTYPE_CLEANUP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CLEANUP"]._serialized_options = b'\212\326\033\013\n\tTxCleanup'
  _ETXTYPES.values_by_name["TXTYPE_COMPACT_BORROWED"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COMPACT_BORROWED"]._serialized_options = b'\212\326\033\023\n\021TxCompactBorrowed'
  _ETXTYPES.values_by_name["TXTYPE_COMPACT_TABLE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COMPACT_TABLE"]._serialized_options = b'\212\326\033\020\n\016TxCompactTable'
  _ETXTYPES.values_by_name["TXTYPE_CHANGE_EXCHANGE_SPLIT_ACK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CHANGE_EXCHANGE_SPLIT_ACK"]._serialized_options = b'\212\326\033\032\n\030TxChangeExchangeSplitAck'
  _ETXTYPES.values_by_name["TXTYPE_APPLY_REPLICATION_CHANGES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_APPLY_REPLICATION_CHANGES"]._serialized_options = b'\212\326\033\033\n\031TxApplyReplicationChanges'
  _ETXTYPES.values_by_name["TXTYPE_READ"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_READ"]._serialized_options = b'\212\326\033\010\n\006TxRead'
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_REPLICATION_SOURCE_OFFSETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SPLIT_REPLICATION_SOURCE_OFFSETS"]._serialized_options = b'\212\326\033!\n\037TxSplitReplicationSourceOffsets'
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_LOCK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_LOCK"]._serialized_options = b'\212\326\033\016\n\014TxRemoveLock'
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_LOCK_CHANGE_RECORDS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_LOCK_CHANGE_RECORDS"]._serialized_options = b'\212\326\033\033\n\031TxRemoveLockChangeRecords'
  _ETXTYPES.values_by_name["TXTYPE_VOLATILE_TX_COMMIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_VOLATILE_TX_COMMIT"]._serialized_options = b'\212\326\033\024\n\022TxVolatileTxCommit'
  _ETXTYPES.values_by_name["TXTYPE_VOLATILE_TX_ABORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_VOLATILE_TX_ABORT"]._serialized_options = b'\212\326\033\023\n\021TxVolatileTxAbort'
  _ESIMPLECOUNTERS._serialized_start=97
  _ESIMPLECOUNTERS._serialized_end=1089
  _ECUMULATIVECOUNTERS._serialized_start=1092
  _ECUMULATIVECOUNTERS._serialized_end=6750
  _EPERCENTILECOUNTERS._serialized_start=6753
  _EPERCENTILECOUNTERS._serialized_end=10063
  _ETXTYPES._serialized_start=10066
  _ETXTYPES._serialized_end=14351
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/proto/dq_checkpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/library/yql/dq/proto/dq_checkpoint.proto\x12\rNYql.NDqProto\"\xcd\x01\n\nTStateData\x12\x38\n\x07StateId\x18\x01 \x01(\x0b\x32%.NYql.NDqProto.TStateData.TExtStateIdH\x00\x12\x34\n\tStateData\x18\x02 \x01(\x0b\x32\x1f.NYql.NDqProto.TStateData.TDataH\x00\x1a\x1e\n\x0bTExtStateId\x12\x0f\n\x07StateId\x18\x01 \x01(\r\x1a&\n\x05TData\x12\x0c\n\x04\x42lob\x18\x01 \x01(\x0c\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x42\x07\n\x05State\"K\n\x0cTSourceState\x12\'\n\x04\x44\x61ta\x18\x01 \x03(\x0b\x32\x19.NYql.NDqProto.TStateData\x12\x12\n\nInputIndex\x18\x02 \x01(\x04\"J\n\nTSinkState\x12\'\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x19.NYql.NDqProto.TStateData\x12\x13\n\x0bOutputIndex\x18\x02 \x01(\x04\"W\n\x14TMiniKqlProgramState\x12\'\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x19.NYql.NDqProto.TStateData\x12\x16\n\x0eRuntimeVersion\x18\x02 \x01(\x04\"\xa9\x01\n\x12TComputeActorState\x12;\n\x0eMiniKqlProgram\x18\x01 \x01(\x0b\x32#.NYql.NDqProto.TMiniKqlProgramState\x12,\n\x07Sources\x18\x02 \x03(\x0b\x32\x1b.NYql.NDqProto.TSourceState\x12(\n\x05Sinks\x18\x03 \x03(\x0b\x32\x19.NYql.NDqProto.TSinkStateB\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.proto.dq_checkpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TSTATEDATA._serialized_start=64
  _TSTATEDATA._serialized_end=269
  _TSTATEDATA_TEXTSTATEID._serialized_start=190
  _TSTATEDATA_TEXTSTATEID._serialized_end=220
  _TSTATEDATA_TDATA._serialized_start=222
  _TSTATEDATA_TDATA._serialized_end=260
  _TSOURCESTATE._serialized_start=271
  _TSOURCESTATE._serialized_end=346
  _TSINKSTATE._serialized_start=348
  _TSINKSTATE._serialized_end=422
  _TMINIKQLPROGRAMSTATE._serialized_start=424
  _TMINIKQLPROGRAMSTATE._serialized_end=511
  _TCOMPUTEACTORSTATE._serialized_start=514
  _TCOMPUTEACTORSTATE._serialized_end=683
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/alloc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bydb/core/protos/alloc.proto\x12\rNKikimrConfig\"{\n\x10TAllocatorConfig\x12\x39\n\x05Param\x18\x01 \x03(\x0b\x32*.NKikimrConfig.TAllocatorConfig.ParamEntry\x1a,\n\nParamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x18\n\x16ru.yandex.kikimr.protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.alloc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TALLOCATORCONFIG_PARAMENTRY._options = None
  _TALLOCATORCONFIG_PARAMENTRY._serialized_options = b'8\001'
  _TALLOCATORCONFIG._serialized_start=46
  _TALLOCATORCONFIG._serialized_end=169
  _TALLOCATORCONFIG_PARAMENTRY._serialized_start=125
  _TALLOCATORCONFIG_PARAMENTRY._serialized_end=169
# @@protoc_insertion_point(module_scope)
